Citing splinebox
================

If you use splinebox in the context of scientific publication, please cite it as follows.
Note, that you will have to fill in the version yourself. If you are unsure what version you are running,
you can find out by running

.. code-block:: python

   import splinebox
   print(splinbox.__version__)

BibTeX:

.. code-block::

   @misc{splinebox,
     author = {Aymanns, Florian and Andò, Edward and Uhlmann, Virginie},
     title = {{S}pline{B}ox},
     url = {https://pypi.org/project/splinebox/},
     doi = {10.5281/zenodo.13358354},
     note = {{V}ersion V.V.Vb1},
     year = 2024,
   }
